@@ -37,3 +37,7 @@ make \
 git config --system http.sslVerify true
 git config --system http.sslCAPath "${PREFIX}/ssl/cacert.pem"
 git config --system http.sslCAInfo "${PREFIX}/ssl/cacert.pem"
+
+# Install completion files
+mkdir -p $PREFIX/share/bash-completion/completions
+cp contrib/completion/git-completion.bash $PREFIX/share/bash-completion/completions/git
